@@ -19,9 +19,9 @@
 
 #include "agenttype.h"
 #include "agentmanager.h"
-#include "tracerinterface.h"
 #include "libs/xdgbasedirs_p.h"
 #include "libs/capabilities_p.h"
+#include "akdebug.h"
 
 #include <QSettings>
 
@@ -61,16 +61,27 @@ bool AgentType::load(const QString & fileName, AgentManager * manager)
   capabilities = file.value( "X-Akonadi-Capabilities" ).toStringList();
   exec = file.value( "Exec" ).toString();
   identifier = file.value( "X-Akonadi-Identifier" ).toString();
+  launchMethod = Process; // Save default
+
+  const QString method = file.value( "X-Akonadi-LaunchMethod" ).toString();
+  if ( method.compare( QLatin1String( "AgentProcess" ), Qt::CaseInsensitive ) == 0 ) {
+    launchMethod = Process;
+  } else if ( method.compare( QLatin1String( "AgentServer" ), Qt::CaseInsensitive ) == 0 ) {
+    launchMethod = Server;
+  } else if ( method.compare( QLatin1String( "AgentLauncher" ), Qt::CaseInsensitive ) == 0 ) {
+    launchMethod = Launcher;
+  } else if ( !method.isEmpty() ) {
+    akError() << Q_FUNC_INFO << "Invalid exec method:" << method << "falling back to AgentProcess";
+  }
+
   file.endGroup();
 
   if ( identifier.isEmpty() ) {
-    manager->tracer()->error( QLatin1String( "AgentType::readInfo" ),
-                             QString( "Agent desktop file '%1' contains empty identifier" ).arg( fileName ) );
+    akError() << Q_FUNC_INFO << "Agent desktop file" << fileName << "contains empty identifier";
     return false;
   }
   if ( exec.isEmpty() ) {
-    manager->tracer()->error( QLatin1String( "AgentType::readInfo" ),
-                    QString( "Agent desktop file '%1' contains empty Exec entry" ).arg( fileName ) );
+    akError() << Q_FUNC_INFO << "Agent desktop file" << fileName << "contains empty Exec entry";
     return false;
   }
 
