@@ -38,7 +38,7 @@ class HandlerHelperTest : public QObject
 
       Collection c;
       c.setCachePolicyInherit( true );
-      QTest::newRow( "inherit" ) << c << QByteArray( "CACHEPOLICY (INHERIT true INTERVAL 0 CACHETIMEOUT 0 SYNCONDEMAND false LOCALPARTS ())" );
+      QTest::newRow( "inherit" ) << c << QByteArray( "CACHEPOLICY (INHERIT true INTERVAL -1 CACHETIMEOUT -1 SYNCONDEMAND false LOCALPARTS ())" );
 
       c.setCachePolicyInherit( false );
       c.setCachePolicyCheckInterval( 1 );
@@ -69,6 +69,13 @@ class HandlerHelperTest : public QObject
 
       QStack<Collection> ancestors;
       Collection c;
+
+      c.setId( 10 );
+      c.setRemoteId( "sl\\ash" );
+      ancestors.push ( c );
+      QTest::newRow( "slash" ) << 1 << ancestors << QByteArray( "ANCESTORS ((10 \"sl\\\\ash\"))" );
+
+      ancestors.clear();
       c.setId( 1 );
       c.setRemoteId( "r1" );
       ancestors.push( c );
